@@ -49,17 +49,21 @@ class ColMeta(ABCMeta):
 
     def __new__(cls, name, bases, local):
         for attr in local:
-            if attr in forbidden_names:
+            if (attr in forbidden_names) or (
+                PREFIX_SEP in attr and not attr.startswith("_")
+            ):
                 raise ValueError(
                     f"Column name can't be either {forbidden_names}. "
+                    f"And can't contain the string {PREFIX_SEP}. "
                     f"{attr} is given"
                 )
             value = local[attr]
             if (
                 callable(value)
                 and not attr.startswith("_")
-                and not isinstance(value, ColMeta)
+                and not isinstance(value, type)
             ):
+                # TODO: all this drawing needs to be revisited
                 local[attr] = decor_w_current(value, name, attr)
         return super().__new__(cls, name, bases, local)
 
@@ -73,13 +77,9 @@ class ColMeta(ABCMeta):
         parent_prefixes = super().__getattribute__(PP_ATT_NAME)
         if isinstance(colval, ColMeta):
             return colval
-        elif isinstance(colval, str):
-            colslug = colval
-        else:
-            colslug = attid
 
         colname = PREFIX_SEP.join(
-            filter(None, [*parent_prefixes, prefix, colslug])
+            filter(None, [*parent_prefixes, prefix, attid])
         )
 
         if CURRENT_CALLER is not None:
@@ -90,8 +90,31 @@ class ColMeta(ABCMeta):
             )
         return colname
 
+    def __getcoltype__(cls, attid):
+        colval = super().__getattribute__(attid.split(PREFIX_SEP)[-1])
+        return colval
+
 
 class ColAccessor(metaclass=ColMeta):
+    """describe raw columns with datatypes
+
+    other than types to describe column type,
+    attributes can be used to describe
+
+    - a foreign key, if it is a string
+    - nested structure, if it is another ColAccessor class
+
+    class TableCols(ColAccessor):
+        col1 = int
+        col2 = str
+        foreign_key1 = "name_of_key"
+
+        class SubCols(ColAccessor):
+            _prefix = "something"  # sets prefix
+            ...
+
+    """
+
     __parent_prefixes__ = DEFAULT_PP  # should never be set manually
     _prefix = DEFAULT_PREFIX
 
@@ -145,6 +168,10 @@ def allcols(cls: Union[Type[ColAccessor], Type[ColAssigner]]):
     return out
 
 
+def get_col_type(accessor: Type[ColAccessor], attname: str):
+    return accessor.__getcoltype__(attname)
+
+
 def decor_w_current(f, clsname, attr):
     @wraps(f)
     def wrapper(*args, **kwds):
